<p align="center">
  <a href="https://hrflow.ai">
    <img alt="hrflow" src="https://img.riminder.net/logo-hrflow.svg" width="120" />
  </a>
</p>
<h1 align="center">
  HrFlow.ai connectors
</h1>

![GitHub Repo stars](https://img.shields.io/github/stars/Riminder/hrflow-connectors?style=social) ![](https://img.shields.io/github/v/release/Riminder/hrflow-connectors) ![](https://img.shields.io/github/license/Riminder/hrflow-connectors)

# 💼 About HrFlow.ai

**[HrFlow.ai](https://hrflow.ai/) is on a mission to make AI and data integration pipelines a commodity in the HR Industry:**

  1. **Unify**: Link your Talent Data channels with a few clicks, so they can share data.
  2. **Understand**: Leverage our AI solutions to process your Talent Data.
  3. **Automate**: Sync data between your tools and build workflows that meet your business logic.

<p align="center">
  <a href="https://hrflow.ai">
    <img alt="hrflow" src="https://hrflow-ai.imgix.net/corporate.svg"/>
  </a>
</p>

<br/>

# 💻 About **HrFlow-Connectors**

**HrFlow-Connectors** is an open-source project created by HrFlow.ai to democratize Talent Data integration within the HR Tech landscape.

We invite developers to join us in our mission to bring AI and data integration to the HR industr, as a developper you can:

- Create new connectors quickly and easily with our low-code connector approach and abstracted concepts
- Contribute to the Connectors' framework with your own code
- Leverage our AI solutions to process your Talent Data
- Sync data between your tools and build workflows that meet your business logic
- Link your Talent Data channels with a few clicks, so they can share data

<p align="center">
<image src=https://user-images.githubusercontent.com/57711045/215884679-33f754e2-2a21-4aad-97c8-181f6d75235e.png width=90% height=100% >
</p>

📃 **More instructions are available in the Documentation section below**

# 🤝 List of Connectors (ATS/CRM/HCM)

| Name                                                                                                                                      | Type                 | Available         | Release date   | Last update     | Pull profile list action | Pull job list action | Push profile action | Push job action |
|-------------------------------------------------------------------------------------------------------------------------------------------|----------------------|--------------------|----------------|-----------------|---------------------|-----------------|-------------------------|----------------------|
| **ADP**                                                                                                                                   | HCM            | 🎯                 |                |                 |                     |                 |                         |                      |
| **Applicantstack**                                                                                                                              | ATS                  | 🎯                 |                |                 |                     |                 |                         |                      |
| **Ashby**                                                                                                                              | ATS                  | 🎯                 |                |                 |                     |                 |                         |                      |
| **BambooHR**                                                                                                                              | ATS                  | 🎯                 |                |                 |                     |                 |                         |                      |
| **BizMerlinHR**                                                                                                                              | ATS                  | 🎯                 |                |                 |                     |                 |                         |                      |
| **Beetween**                                                                                                                              | ATS                  | 🎯                 |                |                 |                     |                 |                         |                      |
| [**Bullhorn**](./src/hrflow_connectors/connectors/bullhorn/README.md) | ATS | :white_check_mark: | *26/01/2022* | *30/10/2023* | :white_check_mark: | :white_check_mark: | :white_check_mark: | :x: |
| [**Breezy HR**](./src/hrflow_connectors/connectors/breezyhr/README.md) | ATS | :white_check_mark: | *19/01/2022* | *04/09/2023* | :x: | :white_check_mark: | :x: | :x: |
| **CATS**                                                                                                                              | ATS                  | 🎯                 |                |                 |                     |                 |                         |                      |
| **Cegid (Meta4)**                                                                                                                                 |      ATS                | 🎯                 |                |                 |                     |                 |                         |                      |
| [**Ceridian**](./src/hrflow_connectors/connectors/ceridian/README.md) | HCM | :white_check_mark: | *19/01/2022* | *04/09/2023* | :x: | :white_check_mark: | :x: | :x: |
| **ClockWork**                                                                                                                              | ATS                  | 🎯                 |                |                 |                     |                 |                         |                      |
| **Comeet**                                                                                                                              | ATS                  | 🎯                 |                |                 |                     |                 |                         |                      |
| **Cornerstone OnDemand**                                                                                                                  |  ATS                    | 🎯                 |                |                 |                     |                 |                         |                      |
| **Crosstalent**                                                                                                                           | ATS                  | :hourglass:       | *19/01/2022*   |                 |                     |                 |                         |                      |
| [**DigitalRecruiters**](./src/hrflow_connectors/connectors/digitalrecruiters/README.md) | ATS | :white_check_mark: | *17/08/2023* | *23/11/2023* | :white_check_mark: | :white_check_mark: | :white_check_mark: | :x: |
|**EngageATS**                                                                                                                              | ATS                  | 🎯                 |                |                 |                     |                 |                         |                      |
| **EOLIA Software**                                                                                                                        | ATS                  | 🎯                 |                |                 |                     |                 |                         |                      |
| **Eploy**                                                                                                                              | ATS                  | 🎯                 |                |                 |                     |                 |                         |                      |
| **Fieldglass SAP**                                                                                                                        | ATS  | 🎯                 |                |                 |                     |                 |                         |                      |
| **Flatchr**                                                                                                                               | ATS                  | :hourglass:       | *21/04/2022*   |                 |                     |                 |                         |                      |
| **Fountain**                                                                                                                              | ATS                  | 🎯                 |                |                 |                     |                 |                         |                      |
| **Freshteam**                                                                                                                              | ATS                  | 🎯                 |                |                 |                     |                 |                         |                      |
| [**Greenhouse**](./src/hrflow_connectors/connectors/greenhouse/README.md) | ATS | :white_check_mark: | *19/01/2022* | *30/10/2023* | :x: | :white_check_mark: | :white_check_mark: | :x: |
| **Harbour ATS**                                                                                                                              | ATS                  | 🎯                 |                |                 |                     |                 |                         |                      |
| **Homerun**                                                                                                                              | ATS                  | 🎯                 |                |                 |                     |                 |                         |                      |
| **HR Cloud**                                                                                                                              | ATS                  | 🎯                 |                |                 |                     |                 |                         |                      |
| [**Hubspot**](./src/hrflow_connectors/connectors/hubspot/README.md) | CRM | :white_check_mark: | *27/10/2022* | *30/10/2023* | :x: | :x: | :white_check_mark: | :x: |
| **ICIMS**                                                                                                                             | ATS                 | 🎯                  |                |               |
| **Infinite BrassRing**                                                                                                                              | ATS                  | 🎯                 |                |                 |                     |                 |                         |                      |
| **JazzHR**                                                                                                                              | ATS                  | 🎯                 |                |                 |                     |                 |                         |                      |
| **Job Adder**                                                                                                                              | ATS                  | 🎯                 |                |                 |                     |                 |                         |                      |
| **Jobsoid**                                                                                                                              | ATS                  | 🎯                 |                |                 |                     |                 |                         |                      |
| **Jobvite**                                                                                                                              | ATS                  | 🎯                 |                |                 |                     |                 |                         |                      |
| **Jobaffinity**                                                                                                                       | ATS                 | 🎯                  |                |               |
| **Jobvite**                                                                                                                           |   ATS                  | 🎯                  |                |               |
| **Kronos (UKG)**                                                                                                                      | HCM           | 🎯                  |                |               |
| **Lano**                                                                                                                              | ATS                  | 🎯                 |                |                 |                     |                 |                         |                      |
| [**Lever**](./src/hrflow_connectors/connectors/lever/README.md) | ATS | :white_check_mark: | *18/08/2023* | *23/11/2023* | :white_check_mark: | :white_check_mark: | :white_check_mark: | :x: |
| **Mailchimp**                                                                                                                         | Marketing Tools     | 🎯                  |                |               |
| **Microsoft Dynamics**                                                                                                                | HCM           | 🎯                  |                |               |
| **Oracle**                                                                                                                            | HCM          | 🎯                  |                |               |
| **Personio**                                                                                                                              | ATS                  | 🎯                 |                |                 |                     |                 |                         |                      |
| **Polymer**                                                                                                                              | ATS                  | 🎯                 |                |                 |                     |                 |                         |                      |
| [**Recruitee**](./src/hrflow_connectors/connectors/recruitee/README.md) | ATS | :white_check_mark: | *30/10/2022* | *04/09/2023* | :x: | :white_check_mark: | :white_check_mark: | :x: |
| **RecruitBox**                                                                                                                        |       ATS              | 🎯                  |                |               |
| **RecruiterFlow**                                                                                                                              | ATS                  | 🎯                 |                |                 |                     |                 |                         |                      |
| **Recruitive**                                                                                                                              | ATS                  | 🎯                 |                |                 |                     |                 |                         |                      |
| [**SAPSuccessfactors**](./src/hrflow_connectors/connectors/sapsuccessfactors/README.md) | ATS | :white_check_mark: | *19/01/2022* | *30/10/2023* | :x: | :white_check_mark: | :white_check_mark: | :x: |
| [**Salesforce**](./src/hrflow_connectors/connectors/salesforce/README.md) | CRM | :white_check_mark: | *03/08/2023* | *04/12/2023* | :white_check_mark: | :white_check_mark: | :white_check_mark: | :x: |
| [**Smartrecruiters**](./src/hrflow_connectors/connectors/smartrecruiters/README.md) | ATS | :white_check_mark: | *21/03/2022* | *30/10/2023* | :x: | :white_check_mark: | :white_check_mark: | :x: |
| [**Taleez**](./src/hrflow_connectors/connectors/taleez/README.md) | ATS | :white_check_mark: | *19/01/2022* | *04/09/2023* | :x: | :white_check_mark: | :white_check_mark: | :x: |
| **Talentlyft**                                                                                                                              | ATS                  | 🎯                 |                |                 |                     |                 |                         |                      |
| **TalentReef**                                                                                                                              | ATS                  | 🎯                 |                |                 |                     |                 |                         |                      |
| [**Talentsoft**](./src/hrflow_connectors/connectors/talentsoft/README.md) | HCM | :white_check_mark: | *19/04/2022* | *31/01/2024* | :white_check_mark: | :white_check_mark: | :white_check_mark: | :x: |
| **Talentlink**                                                                                                                        |    ATS                 | 🎯                  |                |               |
| **TalentReef**                                                                                                                        |   ATS                  | 🎯                  |                |               |
| [**Teamtailor**](./src/hrflow_connectors/connectors/teamtailor/README.md) | ATS | :white_check_mark: | *06/10/2022* | *04/09/2023* | :x: | :white_check_mark: | :white_check_mark: | :x: |
| **Twilio**                                                                                                                            | Automation     | 🎯                  |                |               |
| **Ultimate Software (UKG)**                                                                                                           |  ATS                   | 🎯                  |                |               |
| [**Waalaxy**](./src/hrflow_connectors/connectors/waalaxy/README.md) | Automation | :white_check_mark: | *18/11/2022* | *04/09/2023* | :x: | :x: | :x: | :x: |
| [**Workable**](./src/hrflow_connectors/connectors/workable/README.md) | HCM | :white_check_mark: | *27/09/2022* | *30/10/2023* | :x: | :white_check_mark: | :white_check_mark: | :x: |
| **Workday**                                                                                                                           | HCM           | :heavy_check_mark: |                |               |

- :white_check_mark: : Done
- :hourglass: : Work in progress
- 🎯 : Backlog

# 🤝 List of Connectors (Job Boards)

| Name                                                                                                                                      | Type                 | Available         | Release date   | Last update     | Pull profile list action | Pull job list action | Push profile action | Push job action |
|-------------------------------------------------------------------------------------------------------------------------------------------|----------------------|--------------------|----------------|-----------------|---------------------|-----------------|-------------------------|----------------------|
| **ADENCLASSIFIEDS**                                                                                                                       | Job Board            | 🎯                 |                |                 |                     |                 |                         |                      |
| [**Adzuna**](./src/hrflow_connectors/connectors/adzuna/README.md) | Job Board | :white_check_mark: | *08/09/2022* | *04/09/2023* | :x: | :white_check_mark: | :x: | :x: |
| **Agefiph**                                                                                                                               | Job Board            | 🎯                 |                |                 |                     |                 |                         |                      |
| **APEC**                                                                                                                                  | Job Board            | 🎯                 |                |                 |                     |                 |                         |                      |
| **Cadreemploi**                                                                                                                           | Job Board            | 🎯                 |                |                 |                     |                 |                         |                      |
| **Cornerjob**                                                                                                                             | Job Board            | 🎯                 |                |                 |                     |                 |                         |                      |
| **Distrijob**                                                                                                                             | Job Board            | 🎯                 |                |                 |                     |                 |                         |                      |
| **Engagement Jeunes**                                                                                                                     | Job Board            | 🎯                 |                |                 |                     |                 |                         |                      |
| **FashionJobs**                                                                                                                           | Job Board            | 🎯                 |                |                 |                     |                 |                         |                      |
| **Glassdoor**                                                                                                                             | Job Board            | 🎯                 |                |                 |                     |                 |                         |                      |
| **GoldenBees**                                                                                                                            | Job Board            | 🎯                 |                |                 |                     |                 |                         |                      |
| **Handicap-Job**                                                                                                                      | Job Board           | 🎯                  |                |               |
| **HelloWork**                                                                                                                         | Job Board           | 🎯                  |                |               |
| **Indeed**                                                                                                                            | Job Board           | 🎯                  |                |               |
| **Inzojob**                                                                                                                           | Job Board           | 🎯                  |                |               |
| **Jobijoba**                                                                                                                          | Job Board           | 🎯                  |                |               |
| [**Jobology**](./src/hrflow_connectors/connectors/jobology/README.md) | Job Board | :white_check_mark: | *21/12/2022* | *19/02/2024* | :x: | :x: | :x: | :x: |
| **Jobrapido**                                                                                                                         | Job Board           | 🎯                  |                |               |
| **JobTeaser**                                                                                                                         | Job Board           | 🎯                  |                |               |
| **Jobtransport**                                                                                                                      | Job Board           | 🎯                  |                |               |
| **Jobvitae**                                                                                                                          | Job Board           | 🎯                  |                |               |
| **Jooble**                                                                                                                            | Job Board           | 🎯                  |                |               |
| **Keljob**                                                                                                                            | Job Board           | 🎯                  |                |               |
| **Laponi**                                                                                                                            | Job Board           | 🎯                  |                |               |
| **Leboncoin**                                                                                                                         |  Job Board                   | :hourglass:        | *13/07/2022*   |               |
| **LesJeudis**                                                                                                                         | Job Board           | 🎯                  |                |               |
| **LinkedIn**                                                                                                                          | Job Board           | 🎯                  |                |               |
| [**Meteojob**](./src/hrflow_connectors/connectors/meteojob/README.md) | Job Board | :white_check_mark: | *15/02/2024* | *19/02/2024* | :x: | :x: | :x: | :x: |
| **Monster**                                                                                                                           | Job Board           | :hourglass:        | *23/11/2022*   |               |
| **Nuevoo**                                                                                                                            | Job Board           | 🎯                  |                |               |
| **Optioncarriere**                                                                                                                    | Job Board           | 🎯                  |                |               |
| [**Pole Emploi**](./src/hrflow_connectors/connectors/poleemploi/README.md) | Job Board | :white_check_mark: | *15/07/2022* | *04/09/2023* | :x: | :white_check_mark: | :x: | :x: |
| **RegionsJob**                                                                                                                        | Job Board           | 🎯                  |                |               |
| **Staffme**                                                                                                                           | Job Board           | 🎯                  |                |               |
| **Staffsante**                                                                                                                        | Job Board           | 🎯                  |                |               |
| **Tekkit**                                                                                                                            | Job Board           | 🎯                  |                |               |
| **Turnover-IT**                                                                                                                       | Job Board           | 🎯                  |                |               |
| **Welcome To The Jungle**                                                                                                             | Job Board           | 🎯                  |                |               |
| **Wizbii**                                                                                                                            | Job Board           | 🎯                  |                |               |
| **XML**                                                                                                                               | Job Board           | :hourglass:        |                |               |

- :white_check_mark: : Done
- :hourglass: : Work in progress
- 🎯 : Backlog

# 🪄 Quickstart

## What I can do?

With Hrflow Connector, you can **synchronize** and **process** multiple **HR data streams** in just a few lines of code.

You can do any kind of data transfer between HrFlow.ai and external destinations :

- Pull jobs : `External Job flow` :arrow_right: ***`Hrflow.ai Board`***
- Pull profiles : `External Profile flow` :arrow_right: ***`Hrflow.ai Source`***
- Push job : ***`Hrflow.ai Board`*** :arrow_right: `External destination`
- Push profile : ***`Hrflow.ai Source`*** :arrow_right: `External destination`

The features offered by this package:

- **Synchronize an entire data** stream with a ready-to-use solution
- **Synchronize only certain data** in a stream meeting a condition defined by you : [`logics`](DOCUMENTATION.md#logics)
- **Format the data as you wish** or use the default formatting that we propose adapted to each connector : [`format`](DOCUMENTATION.md#format)
- **Leverage the provider *Hrflow.ai's ** Job and Profile Warehouse* with a many available options like [`hydrate_with_parsing`](src/hrflow_connectors/connectors/hrflow/warehouse.py#L42) or [`update_content`](src/hrflow_connectors/connectors/hrflow/warehouse.py#L39)

## ❓ How to use a connector ?

**Prerequisites**

- [✨ Create a Workspace](https://hrflow.ai/signup/)
- [🔑 Get your API Key](https://developers.hrflow.ai/docs/api-authentification)

1. Spin of a terminal shell
2. **`pip install hrflow-connectors`**
3. Pick the connector you would like to use. Let's say it's **SAPSuccessFactors**

🏁 **TADA! You have just used your first connector.**

## 📖 Documentation

To find out **more about the HrFlow.ai Connectors framework** take a look at the [📖 documentation](DOCUMENTATION.md).

## 💡 Contributions

Please feel free to contribute to the quality of this content by
submitting PRs for improvements to code, architecture, etc.

Any contributions you make to this effort are of course greatly
appreciated.

👉 **To find out more about how to proceed, the rules and conventions to follow, read carefully [`CONTRIBUTING.md`](CONTRIBUTING.md).**

# 🔗 Resources

- Our Developers documentation : <https://developers.hrflow.ai/>

- Our API list (Parsing, Revealing, Embedding, Searching, Scoring, Reasoning) : <https://www.hrflow.ai/api>
- Our cool demos labs : <https://labs.hrflow.ai>

# 🚀 Upcoming Steps and Future Improvements

The project is now in a stable state, however there are still some features and modifications that can be added to further improve the project.

**Next features** :

- Add base classes for connectors actions to inherit from when developping new connectors  🚧

The development team is always open to feedback and new ideas from users, so if you have any suggestions or ideas on how to improve the project, feel free to contact us!

# 📃 License

See the [`LICENSE`](LICENSE) file for licensing information.
